# SCM-Helper
Helper tool for [Swim Club Manager](https://www.swimclubmanager.co.uk/).

Download latest [Windows Version](https://github.com/ColinRobbins/scm-helper/raw/master/download/scm.zip).
# Features
* Works on [Windows](https://github.com/ColinRobbins/scm-helper/wiki/Windows-Installation), [Linux](https://github.com/ColinRobbins/scm-helper/wiki/Linux-Installation) or [Apple](https://github.com/ColinRobbins/scm-helper/wiki/Apple-Installation) devices
* [Backup and Restore](https://github.com/ColinRobbins/scm-helper/wiki/Backup-and-Restore) of SCM data
* Verification of member details
* Check session and group consistency
* Check consistency of [Swim England](https://github.com/ColinRobbins/scm-helper/wiki/Swim-England) registrations
* Check [Facebook](https://github.com/ColinRobbins/scm-helper/wiki/Facebook) group members are club members
* Automatic [fixing](https://github.com/ColinRobbins/scm-helper/wiki/Fixing) of some errors
* Generation of [swimming records](https://github.com/ColinRobbins/scm-helper/wiki/Records)
* Generation of [email lists](https://github.com/ColinRobbins/scm-helper/wiki/Email-Lists) based on group/class/gender/age
* Report on DBS and Safeguarding issue
* Report on swimmers not attending
* Report on swimmers whose confirmation of details has expired
* Fully [configurable](https://github.com/ColinRobbins/scm-helper/wiki/Configuration) (without programming skills)
# Documentation
See [documentation](https://github.com/ColinRobbins/scm-helper/wiki) on GitHub for installation and usage instructions.
# Change Log
See [changelog](CHANGELOG.md)
## Author
* [Colin Robbins](https://github.com/ColinRobbins)
